@@ -516,6 +516,8 @@ netstatus_dialog_detect_configuration_tool (NetstatusDialogData *dialog_data)
       return;
     }
 
+  g_free (config_tool);
+
   for (i = 0; i < G_N_ELEMENTS (network_config_tools); i++)
     {
       if (netstatus_dialog_check_config_tool (dialog_data, network_config_tools [i]))
@@ -673,23 +675,6 @@ netstatus_dialog_setup_device_support (NetstatusDialogData *data,
   netstatus_dialog_update_device_support (data);
 }
 
-static void
-netstatus_dialog_set_icon (GtkWidget *dialog)
-{
-  GtkIconTheme *icon_theme;
-  GtkIconInfo  *icon_info;
-
-  icon_theme = gtk_icon_theme_get_for_screen (gtk_window_get_screen (GTK_WINDOW (dialog)));
-
-  if ((icon_info = gtk_icon_theme_lookup_icon (icon_theme, "gnome-netstatus-tx", 48, 0)))
-    {
-      gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
-				     gtk_icon_info_get_filename (icon_info),
-				     NULL);
-      gtk_icon_info_free (icon_info);
-    }
-}
-
 static gboolean
 netstatus_dialog_iface_list_monitor (NetstatusDialogData *data)
 {
@@ -736,7 +721,7 @@ netstatus_dialog_new (NetstatusIface *iface)
   data->dialog = glade_xml_get_widget (xml, "network_status_dialog");
   g_object_set_data (G_OBJECT (data->dialog), "netstatus-dialog-data", data);
 
-  netstatus_dialog_set_icon (data->dialog);
+  gtk_window_set_icon_name(GTK_WINDOW (data->dialog), "gnome-netstatus-tx");	
 
   data->iface = g_object_ref (iface);
   netstatus_connect_signal_while_alive (data->iface,
